@@ -1,8 +1,6 @@
-from __future__ import (absolute_import, division, print_function)
-
-
 # Follows the 4 aspects of service metadata
 
+
 class IServiceIdentificationMetadata:
     """OO-interface to service identification metadata.
     """
@@ -14,7 +12,7 @@ class IServiceIdentificationMetadata:
     keywords = property("""Keyword list (list).""")
     accessconstraints = property("""Explanation of access constraints associated with service (string).""")
     fees = property("""Explanation of fees associated with service (string).""")
-    
+
 
 class IServiceProviderMetadata:
     """OO-interface to service provider metadata.
@@ -68,7 +66,7 @@ class IWebMapService(IService):
     """
 
     def getcapabilities():
-        """Make a request to the WMS, returns an XML document wrapped in a 
+        """Make a request to the WMS, returns an XML document wrapped in a
         Python file object."""
 
     def getmap(**kw):
@@ -84,7 +82,7 @@ class IWebFeatureService(IService):
     """
 
     def getcapabilities():
-        """Make a request to the WFS, returns an XML document wrapped in a 
+        """Make a request to the WFS, returns an XML document wrapped in a
         Python file object."""
 
     def getfeature(**kw):
@@ -99,54 +97,59 @@ class IWebCoverageService(IService):
     # TODO
     pass
 
+
 class ISensorObservationService(IService):
     """Abstraction for an OGC Sensor Observation Service (SOS).
     """
 
     def getcapabilities():
-        """Make a request to the SOS, returns an XML document wrapped in a 
+        """Make a request to the SOS, returns an XML document wrapped in a
         Python file object."""
 
     def describesensor():
-        """Make a request to the SOS, returns an XML document wrapped in a 
+        """Make a request to the SOS, returns an XML document wrapped in a
         Python file object."""
 
     def getobservation():
-        """Make a request to the SOS, returns an XML document wrapped in a 
+        """Make a request to the SOS, returns an XML document wrapped in a
         Python file object."""
 
+
 class IWebProcessingService(IService):
     """
     Abstract interface for an OGC Web Processing Service (WPS).
     """
-    
+
     def getcapabilities(**kw):
         """
         Makes a GetCapabilities request to the remote WPS server,
         returns an XML document wrapped in a python file-like object.
         """
-    
+
     def describeprocess(**kw):
         """
         Makes a DescribeProcess request to the remote WPS server,
         returns a Process object containing all the process metadata.
         """
-        
+
     def execute(**kw):
         """
         Submits an Execute request to the remote WPS server,
-        returns a WPSExecution object, which can be used to monitor the status of the job, and ultimately retrieve the result.
+        returns a WPSExecution object, which can be used to monitor the status of the job,
+        and ultimately retrieve the result.
         """
-        
+
 # Second level metadata interfaces
 
+
 class IOperationMetadata:
     """OO-interface to operation metadata.
     """
 
     name = property("""Operation name (string): GetCapabilities", for example.""")
     formatOptions = property("""List of content types (list).""")
-    methods = property("""Mapping of method descriptors, keyed to HTTP verbs. Items must implement IMethodMetadata (below).""")
+    methods = property(
+        """Mapping of method descriptors, keyed to HTTP verbs. Items must implement IMethodMetadata (below).""")
 
 
 class IMethodMetadata:
@@ -156,6 +159,7 @@ class IMethodMetadata:
     url = property("""Method endpoint URL (string).""")
     # TODO: constraint
 
+
 class IContentMetadata:
     """OO-interface to content metadata.
     """
@@ -166,8 +170,9 @@ class IContentMetadata:
     boundingBoxWGS84 = property("""Four bounding values in WGS coordinates.""")
     crsOptions = property("""List of available coordinate/spatial reference systems (list).""")
     styles = property("""List of style dicts (list).""")
-    timepositions=property("""List of times for which data is available""")
-    defaulttimeposition=property("""Default time position""")
+    timepositions = property("""List of times for which data is available""")
+    defaulttimeposition = property("""Default time position""")
+
 
 class iSensorObservationServiceContentMetadata(IContentMetadata):
     """Extension class for SOS specifics"""
@@ -175,6 +180,7 @@ class iSensorObservationServiceContentMetadata(IContentMetadata):
 
 # XXX: needed?
 
+
 class IContactMetadata:
     """OO-interface to OWS metadata.
 
